@@ -15,17 +15,24 @@ from .__containers import (
     SetContaining,
 )
 from .__float_approx import FloatApprox
+from .__equals import Is
+from .__logicals import And, Not, Or, Xor
 from .__str_match import StringMatchingRegex
 
 
 __all__ = [
+    'And',
     'Any',
     'Anything',
     'DictContainingKeys',
     'DictContainingValues',
     'DictContainingItems',
     'FloatApprox',
+    'Is',
     'ListContaining',
+    'Not',
+    'Or',
     'SetContaining',
     'StringMatchingRegex',
+    'Xor',
 ]
